@@ -34,6 +34,7 @@ def results_vis(
             whether to include the complete training set in the plot or how many traning-set observations to include.
             passed to include_train parameter when plot_type = 'test'.
             ignored when plot_type = 'forecast'.
+        figsize (tuple): default (12,6). size of the resulting figure.
 
     Returns:
         None 
@@ -115,6 +116,7 @@ def results_vis_mv(f_dict, plot_type="forecast", include_train=True, figsize = (
             whether to include the complete training set in the plot or how many traning-set observations to include.
             passed to include_train parameter when plot_type = 'test'.
             ignored when plot_type = 'forecast'.
+        figsize (tuple): default (12,6). size of the resulting figure.
 
     Returns:
         None
@@ -222,8 +224,10 @@ def tune_test_forecast(
             if int, window evaluates over that many steps (2 for 2-step dynamic forecasting, 12 for 12-step, etc.).
             setting this to False or 1 means faster performance, 
             but gives a less-good indication of how well the forecast will perform out x amount of periods.
-        probabilistic (bool): default False.
-            whether to use a probabilistic forecasting process to set confidence intervals.
+        probabilistic (bool, str, or list-like): default False.
+            if bool, whether to use a probabilistic forecasting process to set confidence intervals for all models.
+            if str, the name of a single model to apply a probabilistic process to.
+            if list-like, a list of models to apply a probabilistic process to.
         n_iter (int): default 20.
             how many iterations to use in probabilistic forecasting. ignored if probabilistic = False.
         summary_stats (bool): default False.
@@ -255,6 +259,11 @@ def tune_test_forecast(
             )
         )
     for m in log_progress(models):
+        m_prob = (
+            probabilistic if isinstance(probabilistic,bool) 
+            else m == probabilistic if isinstance(probabilistic,str) 
+            else m in probabilistic
+        )
         call_me = m if suffix is None else m + suffix
         f.set_estimator(m)
         if limit_grid_size is not None:
@@ -267,7 +276,7 @@ def tune_test_forecast(
         f.auto_forecast(
             dynamic_testing=dynamic_testing,
             call_me=call_me,
-            probabilistic=probabilistic,
+            probabilistic=m_prob,
             n_iter=n_iter,
         )
 
